/**
 * @file main.c
 * @author Thomas Weinhold
 * @date 14.02.2011
 * @version 0.1
 *
 * A brief example for the uAC, designed for an ATMega644P.
 * To port this example, just edit this file.
 */
#include <avr/io.h>
#include <avr/interrupt.h>
#include <uAC.h>

//!UASRT Rx interrupt.
ISR(USART0_RX_vect)
{
	//!Hand over the char to uAC
	uAC_RxInput(UDR0);
}

//!A console test command.
void TestCMD (int argc, char *argv[])
{
	uAC_Print("Hello World: \n");
	int i;
	for (i=0;i<argc;i++)
	{
		uAC_Print("%i: %s\n",i,argv[i]);
	}
}

int main (void)
{
	//!Init USART
	//!115k2 8N1
	UCSR0A |= (1<<U2X0);
	UCSR0B |= (1<<RXCIE0) | (1<<RXEN0) | (1<<TXEN0);
	UCSR0C |= (1<<UCSZ01) | (1<<UCSZ00);
	UBRR0 = 16;

	//!Init the uAC
	uAC_Init();
	//!Attach the test command
	uAC_Attach("test",TestCMD);

	//!don't forget enabling interrupts
	sei();

	//!print something
	uAC_Print("This is a simple greeting Text!\n");

	//!The main-loop.
	for(;;)
	{
		//!The uAC_Task() must be called periodically
		uAC_Task();
		//!If there are outgoing chars, send them
		if (uAC_TxAvailable() && (UCSR0A & (1<<UDRE0))) UDR0=uAC_GetTxChar();
	}
}
